==> transmission_1.77.orig.tar.gz: transmission-1.77/macosx/MessageWindowController.h <==
/******************************************************************************
 * $Id: MessageWindowController.h 7659 2009-01-10 23:37:37Z livings124 $
 *
 * Copyright (c) 2006-2009 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>

@interface MessageWindowController : NSWindowController
{
    IBOutlet NSTableView * fMessageTable;
    
    IBOutlet NSPopUpButton * fLevelButton;
    IBOutlet NSButton * fSaveButton, * fClearButton;
    
    NSMutableArray * fMessages;
    NSUInteger fIndex;
    
    NSDictionary * fAttributes;
    
    NSTimer * fTimer;
    
    NSImage * fErrorImage, * fInfoImage, * fDebugImage;
}

- (void) updateLog: (NSTimer *) timer;

- (void) changeLevel: (id) sender;
- (void) clearLog: (id) sender;

- (void) writeToFile: (id) sender;

@end

==> transmission_2.94.orig.tar.gz: transmission-2.94/macosx/MessageWindowController.h <==
/******************************************************************************
 * $Id$
 *
 * Copyright (c) 2006-2012 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>

@interface MessageWindowController : NSWindowController
{
    IBOutlet NSTableView * fMessageTable;
    
    IBOutlet NSPopUpButton * fLevelButton;
    IBOutlet NSButton * fSaveButton, * fClearButton;
    IBOutlet NSSearchField * fFilterField;
    
    NSMutableArray * fMessages, * fDisplayedMessages;
    
    NSDictionary * fAttributes;
    
    NSTimer * fTimer;
    
    NSLock * fLock;
}

- (void) updateLog: (NSTimer *) timer;

- (void) changeLevel: (id) sender;
- (void) changeFilter: (id) sender;
- (void) clearLog: (id) sender;

- (void) writeToFile: (id) sender;

@end
